package com.agri.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.agri.system.domain.SysMessage;

/**
 * 系统消息中心Service接口
 * 
 * @author lld
 * @date 2026-03-26
 */
public interface ISysMessageService  extends IService<SysMessage> {
    /**
     * 查询系统消息中心
     * 
     * @param id 系统消息中心主键
     * @return 系统消息中心
     */
    public SysMessage selectSysMessageById(Long id);

    /**
     * 查询系统消息中心列表
     * 
     * @param sysMessage 系统消息中心
     * @return 系统消息中心集合
     */
    public List<SysMessage> selectSysMessageList(SysMessage sysMessage);

    /**
     * 新增系统消息中心
     * 
     * @param sysMessage 系统消息中心
     * @return 结果
     */
    public int insertSysMessage(SysMessage sysMessage);

    /**
     * 修改系统消息中心
     * 
     * @param sysMessage 系统消息中心
     * @return 结果
     */
    public int updateSysMessage(SysMessage sysMessage);

    /**
     * 批量删除系统消息中心
     * 
     * @param ids 需要删除的系统消息中心主键集合
     * @return 结果
     */
    public int deleteSysMessageByIds(Long[] ids);

    /**
     * 删除系统消息中心信息
     * 
     * @param id 系统消息中心主键
     * @return 结果
     */
    public int deleteSysMessageById(Long id);
}
